pub enum Target {
PeerId(InputPeer),
SpaceId(i64),
}Expand description
Exactly one target must be set: peer_id for one chat/DM, or space_id for all chats in a space.
Variants
Implementations
Sourceimpl Target
impl Target
Sourcepub fn merge<B>(
field: &mut Option<Target>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Target>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.