pub struct AddReactionInput {
pub emoji: String,
pub message_id: i64,
pub peer_id: Option<InputPeer>,
}Expand description
Add reaction input
Fields
emoji: StringEmoji of the reaction
message_id: i64ID of the message that this reaction is for
peer_id: Option<InputPeer>ID of the peer that this reaction is for