pub struct DeleteReactionInput {
pub emoji: String,
pub peer_id: Option<InputPeer>,
pub message_id: i64,
}Expand description
Delete reaction input
Fields
emoji: Stringpeer_id: Option<InputPeer>message_id: i64Trait Implementations
Sourceimpl Clone for DeleteReactionInput
impl Clone for DeleteReactionInput
Sourcefn clone(&self) -> DeleteReactionInput
fn clone(&self) -> DeleteReactionInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteReactionInput
impl Debug for DeleteReactionInput
Sourceimpl Default for DeleteReactionInput
impl Default for DeleteReactionInput
Sourceimpl<'de> Deserialize<'de> for DeleteReactionInput
impl<'de> Deserialize<'de> for DeleteReactionInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for DeleteReactionInput
impl Message for DeleteReactionInput
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DeleteReactionInput
impl PartialEq for DeleteReactionInput
Sourcefn eq(&self, other: &DeleteReactionInput) -> bool
fn eq(&self, other: &DeleteReactionInput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DeleteReactionInput
impl Serialize for DeleteReactionInput
impl StructuralPartialEq for DeleteReactionInput