pub struct SetBotPresenceStateInput {
pub peer_id: Option<InputPeer>,
pub state: Option<BotPresenceState>,
}Fields
peer_id: Option<InputPeer>state: Option<BotPresenceState>Trait Implementations
Sourceimpl Clone for SetBotPresenceStateInput
impl Clone for SetBotPresenceStateInput
Sourcefn clone(&self) -> SetBotPresenceStateInput
fn clone(&self) -> SetBotPresenceStateInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetBotPresenceStateInput
impl Debug for SetBotPresenceStateInput
Sourceimpl Default for SetBotPresenceStateInput
impl Default for SetBotPresenceStateInput
Sourceimpl<'de> Deserialize<'de> for SetBotPresenceStateInput
impl<'de> Deserialize<'de> for SetBotPresenceStateInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for SetBotPresenceStateInput
impl Message for SetBotPresenceStateInput
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SetBotPresenceStateInput
impl PartialEq for SetBotPresenceStateInput
Sourcefn eq(&self, other: &SetBotPresenceStateInput) -> bool
fn eq(&self, other: &SetBotPresenceStateInput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SetBotPresenceStateInput
impl Serialize for SetBotPresenceStateInput
impl StructuralPartialEq for SetBotPresenceStateInput