pub struct UpdateUserSettingsInput {
pub user_settings: Option<UserSettings>,
}Fields
user_settings: Option<UserSettings>Trait Implementations
Sourceimpl Clone for UpdateUserSettingsInput
impl Clone for UpdateUserSettingsInput
Sourcefn clone(&self) -> UpdateUserSettingsInput
fn clone(&self) -> UpdateUserSettingsInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateUserSettingsInput
impl Debug for UpdateUserSettingsInput
Sourceimpl Default for UpdateUserSettingsInput
impl Default for UpdateUserSettingsInput
Sourceimpl<'de> Deserialize<'de> for UpdateUserSettingsInput
impl<'de> Deserialize<'de> for UpdateUserSettingsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for UpdateUserSettingsInput
impl Message for UpdateUserSettingsInput
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for UpdateUserSettingsInput
impl PartialEq for UpdateUserSettingsInput
Sourcefn eq(&self, other: &UpdateUserSettingsInput) -> bool
fn eq(&self, other: &UpdateUserSettingsInput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UpdateUserSettingsInput
impl Serialize for UpdateUserSettingsInput
impl StructuralPartialEq for UpdateUserSettingsInput